"""Namespace contains different stream sources which are suitable for input or output data flow."""
from typing import List, Optional, Dict, Iterable
import enum
import aspose.pycore
import aspose.pydrawing
import aspose.psd
import aspose.psd.asynctask
import aspose.psd.brushes
import aspose.psd.coreexceptions
import aspose.psd.coreexceptions.compressors
import aspose.psd.coreexceptions.imageformats
import aspose.psd.customfonthandler
import aspose.psd.dithering
import aspose.psd.evalute
import aspose.psd.exif
import aspose.psd.exif.enums
import aspose.psd.extensions
import aspose.psd.fileformats
import aspose.psd.fileformats.ai
import aspose.psd.fileformats.bmp
import aspose.psd.fileformats.core
import aspose.psd.fileformats.core.blending
import aspose.psd.fileformats.core.vectorpaths
import aspose.psd.fileformats.jpeg
import aspose.psd.fileformats.jpeg2000
import aspose.psd.fileformats.pdf
import aspose.psd.fileformats.png
import aspose.psd.fileformats.psd
import aspose.psd.fileformats.psd.core
import aspose.psd.fileformats.psd.core.rawcolor
import aspose.psd.fileformats.psd.layers
import aspose.psd.fileformats.psd.layers.adjustmentlayers
import aspose.psd.fileformats.psd.layers.animation
import aspose.psd.fileformats.psd.layers.filllayers
import aspose.psd.fileformats.psd.layers.fillsettings
import aspose.psd.fileformats.psd.layers.gradient
import aspose.psd.fileformats.psd.layers.layereffects
import aspose.psd.fileformats.psd.layers.layerresources
import aspose.psd.fileformats.psd.layers.layerresources.lfx2resources
import aspose.psd.fileformats.psd.layers.layerresources.strokeresources
import aspose.psd.fileformats.psd.layers.layerresources.typetoolinfostructures
import aspose.psd.fileformats.psd.layers.smartfilters
import aspose.psd.fileformats.psd.layers.smartfilters.rendering
import aspose.psd.fileformats.psd.layers.smartobjects
import aspose.psd.fileformats.psd.layers.text
import aspose.psd.fileformats.psd.resources
import aspose.psd.fileformats.psd.resources.enums
import aspose.psd.fileformats.psd.resources.resolutionenums
import aspose.psd.fileformats.tiff
import aspose.psd.fileformats.tiff.enums
import aspose.psd.fileformats.tiff.filemanagement
import aspose.psd.flatarray
import aspose.psd.flatarray.exceptions
import aspose.psd.imagefilters
import aspose.psd.imagefilters.filteroptions
import aspose.psd.imageloadoptions
import aspose.psd.imageoptions
import aspose.psd.interfaces
import aspose.psd.memorymanagement
import aspose.psd.multithreading
import aspose.psd.palettehelper
import aspose.psd.progressmanagement
import aspose.psd.shapes
import aspose.psd.shapesegments
import aspose.psd.sources
import aspose.psd.xmp
import aspose.psd.xmp.schemas
import aspose.psd.xmp.schemas.dublincore
import aspose.psd.xmp.schemas.pdf
import aspose.psd.xmp.schemas.photoshop
import aspose.psd.xmp.schemas.xmpbaseschema
import aspose.psd.xmp.schemas.xmpdm
import aspose.psd.xmp.schemas.xmpmm
import aspose.psd.xmp.schemas.xmprm
import aspose.psd.xmp.types
import aspose.psd.xmp.types.basic
import aspose.psd.xmp.types.complex
import aspose.psd.xmp.types.complex.colorant
import aspose.psd.xmp.types.complex.dimensions
import aspose.psd.xmp.types.complex.font
import aspose.psd.xmp.types.complex.resourceevent
import aspose.psd.xmp.types.complex.resourceref
import aspose.psd.xmp.types.complex.thumbnail
import aspose.psd.xmp.types.complex.version
import aspose.psd.xmp.types.derived

class FileCreateSource(FileSource):
    '''Represents a file source for creation.'''
    
    @overload
    def __init__(self, file_path: str):
        '''Initializes a new instance of the  class.
        
        :param file_path: The file path to create.'''
        ...
    
    @overload
    def __init__(self, file_path: str, is_temporal: bool):
        '''Initializes a new instance of the  class.
        
        :param file_path: The file path to create.
        :param is_temporal: If set to ``true`` the created file will be temporal.'''
        ...
    
    def get_stream_container(self) -> aspose.psd.StreamContainer:
        '''Gets the stream container.
        
        :returns: the stream container.'''
        ...
    
    @property
    def is_temporal(self) -> bool:
        ...
    
    @property
    def file_path(self) -> str:
        ...
    
    ...

class FileOpenSource(FileSource):
    '''Represents a file source for opening.'''
    
    def __init__(self, file_path: str):
        '''Initializes a new instance of the  class.
        
        :param file_path: The file path to open.'''
        ...
    
    def get_stream_container(self) -> aspose.psd.StreamContainer:
        '''Gets the stream container.
        
        :returns: the stream container.'''
        ...
    
    @property
    def is_temporal(self) -> bool:
        ...
    
    @property
    def file_path(self) -> str:
        ...
    
    ...

class FileSource(aspose.psd.Source):
    '''Represents a file source which is capable of files manipulation.'''
    
    def get_stream_container(self) -> aspose.psd.StreamContainer:
        '''Gets the stream container.
        
        :returns: the stream container.'''
        ...
    
    @property
    def is_temporal(self) -> bool:
        ...
    
    ...

class StreamSource(aspose.psd.Source):
    '''Represents a stream source.'''
    
    @overload
    def __init__(self, stream: io.RawIOBase):
        '''Initializes a new instance of the  class.
        
        :param stream: The stream to open.'''
        ...
    
    @overload
    def __init__(self, stream: io.RawIOBase, dispose_stream: bool):
        '''Initializes a new instance of the  class.
        
        :param stream: The stream to open.
        :param dispose_stream: if set to ``true`` the stream will be disposed.'''
        ...
    
    def get_stream_container(self) -> aspose.psd.StreamContainer:
        '''Gets the stream container.
        
        :returns: the stream container.'''
        ...
    
    @property
    def stream(self) -> io.RawIOBase:
        '''Gets the stream.'''
        ...
    
    @property
    def dispose_stream(self) -> bool:
        ...
    
    ...

